import React, { FC } from 'react';
import { SubmitHandler, useForm } from 'react-hook-form';
import { Button } from '@material-ui/core';
import { InputField } from 'components/AuthUser/InputField/InputField';
import { useStyles } from 'components/AuthUser/SignUpForm/useStyles';
import axios from 'axios';
// TODO: Data validation
// TODO: Replace notes with big input field
export const SignUpForm: FC = () => {
  type FormData = {
    username: string;
    password: string;
    firstName: string;
    lastName: string;
    email: string;
  };

  const defaultValues: FormData = {
    username: '',
    password: '',
    firstName: '',
    lastName: '',
    email: '',
  };

  const { control, errors, handleSubmit } = useForm<FormData>({
    defaultValues,
  });

  const onSubmit: SubmitHandler<FormData> = (values: FormData) => {
    axios
      .post(
        '/api/web/seniors/',
        {
          user: {
            username: 'test',
            password: values.password,
            firstName: 'a',
            lastName: 'b',
            email: values.email,
          },
          phone_number: '213432234',
          home_address: {
            address: 'test street, 3',
          },
          member_card_issuer: {
            name: 'test issuer',
          },
          member_card_number: '33333333333',
        },
        {
          headers: {
            'Content-Type': 'application/json',
          },
        },
      )
      .then((res) => console.log(res));
  };

  const classes = useStyles();
  return (
    <>
      <form
        className={classes.form}
        onSubmit={handleSubmit(onSubmit)}
        data-testid="Form"
      >
        <InputField
          name="email"
          control={control}
          rules={{
            validate: (value: string) =>
              /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i.test(value),
            required: {
              value: true,
              message: 'Email is not valid',
            },
          }}
          label="Email"
          error={!!errors.email}
          errorMessage="Insert email"
        />

        <InputField
          name="password"
          control={control}
          rules={{
            minLength: 8,
            maxLength: 60,
            required: {
              value: true,
              message: 'Insert valid password',
            },
          }}
          label="Password"
          error={!!errors.password}
          errorMessage="Insert valid password"
        />
        <Button
          data-testid="Submit"
          type="submit"
          fullWidth
          variant="contained"
          color="primary"
          className={classes.submit}
        >
          Sign Up
        </Button>
      </form>
    </>
  );
};
